
import { convertPromise } from './header.js'
import Permission from '@/js_sdk/wa-permission/permission'
import { SelectLocation } from "./authPerission";
import API from '@/server/common'



// 异步请求
export function getNetworkException(requestList) {
    return Promise.all(requestList)
        .then((res) => {
            // console.log('getNetworkException-res----------', res)
        })
        .catch((err) => {
            if (err.code != "20001") return;
            uni.$util.showToast("网络有点忙, 请刷新试试~");
        })
        .finally(() => {
            // uni.hideLoading()
            // complete()
        });
}

// toast 提示框
export function showToast(title = "", duration = 2000, icon = "none") {
    return new Promise((resolve, reject) =>
        uni.showToast({
            title,
            duration,
            icon,
            success: () => setTimeout(() => resolve(), duration),
            fail: () => reject(),
        })
    );
}

// 切换tabBar的显示和隐藏
export const isLogin = () => {
    let flag = false
    const token = uni.getStorageSync('token')
    token ? flag = true : flag = false
    return flag
}



// 切换tabBar的显示和隐藏
export const switchShowTabbar = async () => {
    const token = uni.getStorageSync('token')
    if (!token) {
        uni.setTabBarItem({
            index: 1,
            visible: false
        })
    } else {
        try {
			const res= await API.initTabBar()			
			const { data }=res.result
			uni.setStorageSync('showIndex',data)
            if (data==true) {
				
                uni.setTabBarItem({
                    index: 1,
                    text: '贷款',
                    visible: true,
                })
            } else {
                uni.setTabBarItem({
                    index: 1,
                    visible: false
                })
            }
        } catch (err) {
            console.log(err, '错误信息')
        }
    }
}
//获取h5url地址信息
export const initSettings=async()=>{
	try{
		const res=await API.initSettings()
		const {h5Url}=res.result
		uni.setStorageSync('mianH5Url',h5Url)
	}catch(err){
		console.log(err,'初始化')
	}
}
// 设备信息
export const loadDevice = async () => {
    convertPromise('getSystemInfo').then(result => {
        const deviceInfo = {
            deviceType: result.deviceType,
            appName: result.appName,
            deviceId: result.deviceId,
            device: result.osName,
            deviceName: result.platform,
            appVersion: result.appWgtVersion,
            osVersion: result.osVersion ? result.osVersion : result.system,
            mobileType: result.model,
            screenHeight: result.screenHeight,
            screenWidth: result.screenWidth,
            resolution: result.windowWidth + '*' + result.screenHeight
        };
        // 本地存储
        uni.setStorage({ key: 'm-device-info', data: JSON.stringify(deviceInfo) });
    }).catch(err => {
        //that.toast('获取设备信息失败')
        uni.showModal({
            title: '"多典花"想访问您的设备信息',
            content: '通过访问您的设备信息，提高您授信通过率。',
            showCancel: false,
            confirmText: '去设置',
            success: function (res) {
                if (res.confirm) {
                    Permission.gotoAppPermissionSetting()
                }
            }
        });
    })
}
/** 获取网络信息 */
export const loadNetwork = () => {
    convertPromise('getNetworkType').then(result => {
        const networkInfo = {
            networkStatus: result.networkType
        };
        
        // 网络信息存储
        uni.setStorage({
            key: 'm-network-info',
            data: JSON.stringify(networkInfo)
        });
    }).catch(err => {
        console.log(err, '获取网络信息失败')
    })
}
/** 获取UDID */
export const loadUuid = () => {
    plus.device.getInfo({
        success: function (e) {
            const deviceInfo = {
                token: e.uuid,
            };
            uni.setStorage({
                key: 'm-load-udid',
                data: JSON.stringify(deviceInfo)
            })
        },
        fail: function (e) {
            console.log('getDeviceInfo failed: ' + JSON.stringify(e));
        }
    });
}
/** 定位信息 */
export const loadLocation = () => {
    // 苹果测试手机如果没有插入手机卡，获取定位之后会解析失败，报错
    SelectLocation(() => {
        convertPromise('getLocation', {
            type: 'wgs84',
            geocode: true
        }).then(result => {
            const locationInfo = {
                lat: String(result.latitude),
                lng: String(result.longitude)

            };
            uni.setStorage({ key: 'm-location-info', data: JSON.stringify(locationInfo) });
        }).catch(err => {
            console.log(err, '获取设备定位信息报错了')
        })
    })
}